@@ -1,8 +1,6 @@
 #' Resolve column name ambiguities
 #'
 #' @description
-#' `r lifecycle::badge("stable")`
-#'
 #' This function ensures that all columns in a `dm` have unique names.
 #'
 #' @details
@@ -15,9 +13,14 @@
 #'
 #' @inheritParams dm_add_pk
 #' @inheritParams rlang::args_dots_empty
-#' @param sep The character variable that separates the names of the table and the names of the ambiguous columns.
-#' @param quiet Boolean.
+#' @param .sep The character variable that separates the names of the table and the names of the ambiguous columns.
+#' @param .quiet Boolean.
 #'   By default, this function lists the renamed columns in a message, pass `TRUE` to suppress this message.
+#' @param .position
+#'   `r lifecycle::badge("experimental")`
+#'   By default, table names are appended to the column names to resolve conflicts.
+#'   Prepending table names was the default for versions before 1.0.0,
+#'   use `"prefix"` to achieve this behavior.
 #'
 #' @return A `dm` whose column names are unambiguous.
 #'
@@ -25,15 +28,21 @@
 #' dm_nycflights13() %>%
 #'   dm_disambiguate_cols()
 #' @export
-dm_disambiguate_cols <- function(dm, sep = ".", ..., quiet = FALSE) {
+dm_disambiguate_cols <- function(dm, .sep = ".", ..., .quiet = FALSE,
+                                 .position = c("suffix", "prefix")) {
   check_not_zoomed(dm)
   check_dots_empty()
-  dm_disambiguate_cols_impl(dm, tables = NULL, sep = sep, quiet = quiet)
+  .position <- arg_match(.position)
+  dm_disambiguate_cols_impl(
+    dm,
+    tables = NULL, sep = .sep, quiet = .quiet,
+    position = .position
+  )
 }
 
-dm_disambiguate_cols_impl <- function(dm, tables, sep = ".", quiet = FALSE) {
+dm_disambiguate_cols_impl <- function(dm, tables, sep = ".", quiet = FALSE, position = "suffix") {
   table_colnames <- get_table_colnames(dm, tables, exclude_pk = FALSE)
-  recipe <- compute_disambiguate_cols_recipe(table_colnames, sep = sep)
+  recipe <- compute_disambiguate_cols_recipe(table_colnames, sep = sep, position = position)
   if (!quiet) explain_col_rename(recipe)
   col_rename(dm, recipe)
 }
@@ -78,11 +87,16 @@ get_table_colnames <- function(dm, tables = NULL, exclude_pk = TRUE) {
 #' @param table_colnames a table containing table name and col names of dm
 #' @param sep separator used to create new names for dupe cols
 #' @noRd
-compute_disambiguate_cols_recipe <- function(table_colnames, sep) {
+compute_disambiguate_cols_recipe <- function(table_colnames, sep, position = "suffix") {
   dupes <- vec_duplicate_detect(table_colnames$column)
   dup_colnames <- table_colnames[dupes, ]
 
-  dup_colnames$new_name <- paste0(dup_colnames$table, sep, dup_colnames$column)
+  if (position == "prefix") {
+    dup_colnames$new_name <- paste0(dup_colnames$table, sep, dup_colnames$column)
+  } else {
+    dup_colnames$new_name <- paste0(dup_colnames$column, sep, dup_colnames$table)
+  }
+
   dup_data <- dup_colnames[c("new_name", "column")]
   dup_data$column_sym <- syms(dup_data$column)
 
