@@ -170,6 +170,19 @@ utils::globalVariables(c(
   "referenced_table_name",
   "referenced_table_schema",
   #
+  # cardinalities
+  "x_label",
+  "y_label",
+  #
+  # deconstruct
+  "ref_uuid",
+  "child_data",
+  "child_uuid",
+  "parent_data",
+  "parent_uuid",
+  #
+  "g_table_names",
+  #
   # keep this to avoid dealing with trailing commas
   NULL
 ))
