@@ -1,17 +1,15 @@
-#' \pkg{utils} table manipulation methods for `zoomed_dm` objects
+#' \pkg{utils} table manipulation methods for `dm_zoomed` objects
 #'
 #' @description
-#' `r lifecycle::badge("stable")`
-#'
 #' Extract the first or last rows from a table.
-#' Use these methods without the '.zoomed_dm' suffix (see examples).
+#' Use these methods without the '.dm_zoomed' suffix (see examples).
 #' The methods for regular `dm` objects extract the first or last tables.
 #'
-#' @param x object of class `zoomed_dm`
+#' @param x object of class `dm_zoomed`
 #' @inheritParams utils::head
 #' @rdname utils_table_manipulation
 #'
-#' @return A `zoomed_dm` object.
+#' @return A `dm_zoomed` object.
 #'
 #' @details see manual for the corresponding functions in \pkg{utils}.
 #'
@@ -22,14 +20,14 @@
 #' zoomed
 #' dm_insert_zoomed(zoomed, new_tbl_name = "head_flights")
 #' @export
-head.zoomed_dm <- function(x, n = 6L, ...) {
+head.dm_zoomed <- function(x, n = 6L, ...) {
   # dm method provided by utils
   replace_zoomed_tbl(x, head(tbl_zoomed(x), n, ...))
 }
 
 #' @rdname utils_table_manipulation
 #' @export
-tail.zoomed_dm <- function(x, n = 6L, ...) {
+tail.dm_zoomed <- function(x, n = 6L, ...) {
   # dm method provided by utils
   replace_zoomed_tbl(x, tail(tbl_zoomed(x), n, ...))
 }
