@@ -6,9 +6,9 @@ if (is_this_a_test()) {
     tbl_sum.tbl_sql <- function(x, ...) c()
     s3_register("tibble::tbl_sum", "tbl_sql", tbl_sum.tbl_sql)
     s3_register("pillar::tbl_sum", "tbl_sql", tbl_sum.tbl_sql)
+    tbl_format_header.tbl_sql <- function(x, ...) invisible()
+    s3_register("pillar::tbl_format_header", "tbl_sql", tbl_format_header.tbl_sql)
   }
+  # Not sure why this works without s3_register(), and is also required
   tbl_sum.tbl_df <- function(x, ...) c()
-  if (packageVersion("pillar") < "1.4.99") {
-    s3_register("tibble::tbl_sum", "tbl_df", tbl_sum.tbl_df)
-  }
 }
