@@ -103,8 +103,9 @@ test_that("DB helpers work for Postgres", {
 })
 
 test_that("DB helpers work for other DBMS than MSSQL or Postgres", {
-  skip_if_src("mssql")
-  skip_if_src("postgres")
+  # FIXME: Why does it fail for those databases?
+  skip_if_src("mssql", "postgres")
+
   # for other DBMS than "MSSQL" or "Postgrs", get_src_tbl_names() translates to `src_tbls_impl()`
   con_db <- my_db_test_src()$con
   dbWriteTable(
@@ -116,12 +117,22 @@ test_that("DB helpers work for other DBMS than MSSQL or Postgres", {
     try(dbExecute(con_db, "DROP TABLE test_db_helpers"))
   })
 
+  skip_if_src("maria")
+
   # test for 2 warnings and if the output contains the new table
   expect_dm_warning(
     expect_dm_warning(
-      expect_true("test_db_helpers" %in% get_src_tbl_names(my_db_test_src(), schema = "schema", dbname = "dbname")),
+      expect_true("test_db_helpers" %in% names(get_src_tbl_names(my_db_test_src(), schema = "schema", dbname = "dbname"))),
       class = "arg_not"
     ),
     class = "arg_not"
   )
+
+  skip_if_src("mssql", "postgres")
+
+  # test for warning and if the output contains the new table
+  expect_dm_warning(
+    expect_true("test_db_helpers" %in% names(get_src_tbl_names(my_db_test_src(), dbname = "dbname"))),
+    class = "arg_not"
+  )
 })
