@@ -1,3 +1,235 @@
+test_that("dm() API", {
+  expect_snapshot({
+    dm(a = tibble(), a = tibble(), .name_repair = "unique")
+    dm(a = tibble(), a = tibble(), .name_repair = "unique", .quiet = TRUE)
+  })
+  expect_snapshot(error = TRUE, {
+    dm(a = tibble(), a = tibble())
+  })
+  expect_snapshot(error = TRUE, {
+    dm(a = dm())
+  })
+  expect_snapshot(error = TRUE, {
+    dm(a = tibble(), dm_zoom_to(dm_for_filter(), tf_1))
+  })
+})
+
+test_that("dm() works for adding tables", {
+  # is a table added?
+  expect_identical(
+    length(dm_get_tables(dm(dm_for_filter(), data_card_1()))),
+    7L
+  )
+
+  # can I retrieve the tibble under its old name?
+  expect_equivalent_tbl(
+    dm(dm_for_filter(), data_card_1())[["data_card_1()"]],
+    data_card_1()
+  )
+
+  # can I retrieve the tibble under a new name?
+  expect_equivalent_tbl(
+    dm(dm_for_filter(), test = data_card_1())[["test"]],
+    data_card_1()
+  )
+
+  # use special names with :=
+  expect_identical(
+    names(dm(dm_for_filter(), dm := data_card_1(), repair := data_card_2())),
+    c(names(dm_for_filter()), "dm", "repair")
+  )
+
+  # we accept even weird table names, as long as they are unique
+  expect_equivalent_tbl(
+    dm(dm_for_filter(), . = data_card_1())[["."]],
+    data_card_1()
+  )
+
+  # do I avoid the warning when piping the table but setting the name?
+  expect_silent(
+    expect_equivalent_tbl(
+      dm_for_filter() %>% dm(new_name = data_card_1()) %>% pull_tbl(new_name),
+      data_card_1()
+    )
+  )
+
+  # adding more than 1 table:
+  # 1. Is the resulting number of tables correct?
+  expect_identical(
+    length(dm_get_tables(dm(dm_for_filter(), data_card_1(), data_card_2()))),
+    8L
+  )
+
+  # 2. Is the resulting order of the tables correct?
+  expect_identical(
+    src_tbls_impl(dm(dm_for_filter(), data_card_1(), data_card_2())),
+    c(src_tbls_impl(dm_for_filter()), "data_card_1()", "data_card_2()")
+  )
+
+  # Is an error thrown in case I try to give the new table an old table's name if `repair = "check_unique"`?
+  expect_snapshot(error = TRUE, {
+    dm(dm_for_filter(), tf_1 = data_card_1(), .name_repair = "check_unique")
+  })
+
+  # are in the default case (`repair = 'unique'`) the tables renamed (old table AND new table) according to "unique" default setting
+  expect_identical(
+    dm(dm_for_filter(), tf_1 = data_card_1(), .name_repair = "unique", .quiet = TRUE) %>% src_tbls_impl(),
+    c("tf_1...1", "tf_2", "tf_3", "tf_4", "tf_5", "tf_6", "tf_1...7")
+  )
+
+  expect_name_repair_message(
+    expect_equivalent_dm(
+      dm(dm_for_filter(), tf_1 = data_card_1(), .name_repair = "unique"),
+      dm_for_filter() %>%
+        dm_rename_tbl(tf_1...1 = tf_1) %>%
+        dm(tf_1...7 = data_card_1())
+    )
+  )
+
+  # can I use dm_select_tbl(), selecting among others the new table?
+  expect_silent(
+    dm(dm_for_filter(), tf_7_new = tf_7()) %>% dm_select_tbl(tf_1, tf_7_new, everything())
+  )
+
+  skip_if_not_installed("dbplyr")
+
+  # error in case table srcs don't match
+  expect_dm_error(
+    dm(dm_for_filter(), data_card_1_duckdb()),
+    "not_same_src"
+  )
+
+  # adding tables to an empty `dm` works for all sources
+  expect_equivalent_tbl(
+    dm(dm(), test = data_card_1_duckdb())$test,
+    data_card_1()
+  )
+})
+
+test_that("dm() for adding tables with compound keys", {
+  expect_snapshot({
+    dm(dm_for_flatten(), res_flat = result_from_flatten()) %>% dm_paste(options = c("select", "keys"))
+  })
+})
+
+test_that("dm() works for dm objects", {
+  expect_equivalent_dm(
+    dm(dm_for_filter()),
+    dm_for_filter()
+  )
+
+  expect_equivalent_dm(
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_disambiguate()),
+    bind_rows(
+      dm_get_def(dm_for_filter()),
+      dm_get_def(dm_for_flatten()),
+      dm_get_def(dm_for_disambiguate())
+    ) %>%
+      new_dm3()
+  )
+})
+
+test_that("are empty_dm() and empty ellipsis handled correctly?", {
+  expect_equivalent_dm(
+    dm(empty_dm()),
+    empty_dm()
+  )
+
+  expect_equivalent_dm(
+    dm(empty_dm(), empty_dm(), empty_dm()),
+    empty_dm()
+  )
+
+  expect_equivalent_dm(
+    dm(),
+    empty_dm()
+  )
+})
+
+test_that("errors: duplicate table names, src mismatches", {
+  expect_snapshot(error = TRUE, {
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_filter())
+  })
+
+  skip_if_not_installed("dbplyr")
+  skip_if_not_installed("duckdb")
+  expect_dm_error(dm(dm_for_flatten(), dm_for_filter_duckdb()), "not_same_src")
+})
+
+test_that("auto-renaming works", {
+  expect_equivalent_dm(
+    expect_name_repair_message(
+      dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique")
+    ),
+    bind_rows(
+      dm_get_def(
+        dm_rename_tbl(
+          dm_for_filter(),
+          tf_1...1 = tf_1,
+          tf_2...2 = tf_2,
+          tf_3...3 = tf_3,
+          tf_4...4 = tf_4,
+          tf_5...5 = tf_5,
+          tf_6...6 = tf_6
+        )
+      ),
+      dm_get_def(dm_for_flatten()),
+      dm_get_def(dm_rename_tbl(
+        dm_for_filter(),
+        tf_1...12 = tf_1,
+        tf_2...13 = tf_2,
+        tf_3...14 = tf_3,
+        tf_4...15 = tf_4,
+        tf_5...16 = tf_5,
+        tf_6...17 = tf_6
+      ))
+    ) %>%
+      new_dm3()
+  )
+
+  expect_silent(
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique", .quiet = TRUE)
+  )
+})
+
+test_that("test error output for src mismatches", {
+  skip_if_not_installed("dbplyr")
+
+  expect_snapshot({
+    writeLines(conditionMessage(expect_error(
+      dm(dm_for_flatten(), dm_for_filter_duckdb())
+    )))
+  })
+})
+
+test_that("output for dm() with dm", {
+  expect_snapshot({
+    dm()
+    dm(empty_dm())
+    dm(dm_for_filter()) %>% collect()
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique", .quiet = TRUE) %>% collect()
+  })
+
+  expect_snapshot(error = TRUE, {
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_filter())
+  })
+
+  expect_snapshot({
+    dm(dm_for_filter(), dm_for_flatten(), dm_for_filter(), .name_repair = "unique") %>% collect()
+  })
+})
+
+test_that("output dm() for dm for compound keys", {
+  expect_snapshot({
+    dm(dm_for_filter(), dm_for_flatten()) %>% dm_paste(options = c("select", "keys"))
+    dm(dm_for_flatten(), dm_for_filter()) %>% dm_paste(options = c("select", "keys"))
+  })
+
+  expect_snapshot({
+    dm(dm_for_flatten(), dm_for_flatten(), .name_repair = "unique") %>% dm_paste(options = c("select", "keys"))
+  })
+})
+
 test_that("can create dm with as_dm()", {
   expect_equivalent_dm(as_dm(dm_get_tables(dm_test_obj())), dm_test_obj())
 })
@@ -15,7 +247,7 @@ test_that("creation of empty `dm` works", {
 test_that("'collect.dm()' collects tables on DB", {
   def <-
     dm_for_filter() %>%
-    dm_filter(tf_1, a > 3) %>%
+    dm_filter(tf_1 = a > 3) %>%
     collect() %>%
     dm_get_def()
 
@@ -23,14 +255,14 @@ test_that("'collect.dm()' collects tables on DB", {
   expect_true(all(is_df))
 })
 
-test_that("'collect.zoomed_dm()' collects tables, with message", {
-  zoomed_dm_for_collect <-
+test_that("'collect.dm_zoomed()' collects tables, with message", {
+  dm_zoomed_for_collect <-
     dm_for_filter() %>%
     dm_zoom_to(tf_1) %>%
     mutate(c = a + 1)
 
   expect_message(
-    out <- zoomed_dm_for_collect %>% collect(),
+    out <- dm_zoomed_for_collect %>% collect(),
     "pull_tbl"
   )
 
@@ -42,7 +274,7 @@ test_that("'compute.dm()' computes tables on DB", {
 
   def <-
     dm_for_filter_duckdb() %>%
-    dm_filter(tf_1, a > 3) %>%
+    dm_filter(tf_1 = a > 3) %>%
     {
       suppress_mssql_message(compute(.))
     } %>%
@@ -52,17 +284,17 @@ test_that("'compute.dm()' computes tables on DB", {
   expect_equal(lengths(remote_names), rep_along(remote_names, 1))
 })
 
-test_that("'compute.zoomed_dm()' computes tables on DB", {
+test_that("'compute.dm_zoomed()' computes tables on DB", {
   skip("Needs https://github.com/tidyverse/dbplyr/pull/649")
 
-  zoomed_dm_for_compute <-
+  dm_zoomed_for_compute <-
     dm_for_filter_duckdb() %>%
     dm_zoom_to(tf_1) %>%
     mutate(c = a + 1)
 
   # without computing
   def <-
-    zoomed_dm_for_compute %>%
+    dm_zoomed_for_compute %>%
     dm_update_zoomed() %>%
     dm_get_def()
 
@@ -71,7 +303,7 @@ test_that("'compute.zoomed_dm()' computes tables on DB", {
 
   # with computing
   def <-
-    suppress_mssql_message(compute(zoomed_dm_for_compute)) %>%
+    suppress_mssql_message(compute(dm_zoomed_for_compute)) %>%
     dm_update_zoomed() %>%
     dm_get_def()
 
@@ -79,7 +311,7 @@ test_that("'compute.zoomed_dm()' computes tables on DB", {
   expect_equal(lengths(remote_names), rep_along(remote_names, 1))
 })
 
-test_that("some methods/functions for `zoomed_dm` work", {
+test_that("some methods/functions for `dm_zoomed` work", {
   expect_identical(
     colnames(dm_zoom_to(dm_for_filter(), tf_1)),
     c("a", "b")
@@ -117,6 +349,11 @@ test_that("`pull_tbl()`-methods work", {
     tf_5()
   )
 
+  expect_equal(
+    pull_tbl(dm_for_filter(), tf_5, keyed = TRUE),
+    dm_get_tables(dm_for_filter(), keyed = TRUE)[["tf_5"]]
+  )
+
   skip_if_src("maria")
   expect_equivalent_tbl(
     dm_for_filter() %>%
@@ -175,7 +412,7 @@ test_that("subsetting `dm` works", {
   expect_equivalent_tbl(dm_for_filter()[["tf_3"]], tf_3())
 })
 
-test_that("subsetting `zoomed_dm` works", {
+test_that("subsetting `dm_zoomed` works", {
   skip_if_remote_src()
   expect_identical(
     dm_zoom_to(dm_for_filter(), tf_2)$c,
@@ -193,7 +430,7 @@ test_that("subsetting `zoomed_dm` works", {
   )
 })
 
-test_that("as.list()-method works for local `zoomed_dm`", {
+test_that("as.list()-method works for local `dm_zoomed`", {
   skip_if_remote_src()
   expect_identical(
     as.list(dm_for_filter() %>% dm_zoom_to(tf_4)),
@@ -237,19 +474,6 @@ test_that("dm_get_con() works", {
   )
 })
 
-test_that("dm_get_filters() works", {
-  expect_identical(
-    dm_get_filters(dm_for_filter()),
-    tibble(table = character(), filter = list(), zoomed = logical())
-  )
-
-  expect_identical(
-    dm_get_filters(dm_filter(dm_for_filter(), tf_1, a > 3, a < 8)),
-    tibble(table = "tf_1", filter = unname(exprs(a > 3, a < 8)), zoomed = FALSE)
-  )
-})
-
-
 test_that("str()", {
   # https://github.com/cynkra/dm/pull/542/checks?check_run_id=2506393322#step:11:88
   skip("FIXME: Unstable on GHA?")
@@ -277,7 +501,7 @@ test_that("output", {
       format()
 
     nyc_flights_dm %>%
-      dm_filter(flights, origin == "EWR") %>%
+      dm_filter(flights = (origin == "EWR")) %>%
       collect()
   })
 })
@@ -295,21 +519,22 @@ test_that("output for compound keys", {
 
   expect_snapshot({
     copy_to(nyc_comp(), mtcars, "car_table")
-    dm_add_tbl(nyc_comp(), car_table)
+    dm(nyc_comp(), car_table)
     nyc_comp() %>%
       collect()
     nyc_comp() %>%
-      dm_filter(flights, day == 10) %>%
-      compute() %>%
+      dm_filter(flights = (day == 10)) %>%
       collect() %>%
-      dm_get_def()
+      dm_get_def() %>%
+      select(-uuid)
     nyc_comp() %>%
       dm_zoom_to(weather) %>%
       mutate(origin_new = paste0(origin, " airport")) %>%
       compute() %>%
       dm_update_zoomed() %>%
       collect() %>%
-      dm_get_def()
+      dm_get_def() %>%
+      select(-uuid)
     nyc_comp() %>%
       dm_zoom_to(weather) %>%
       collect()
@@ -354,7 +579,7 @@ test_that("glimpse.dm() works", {
   })
 })
 
-test_that("glimpse.zoomed_dm() works", {
+test_that("glimpse.dm_zoomed() works", {
   skip_if_remote_src()
   expect_snapshot({
     # doesn't have foreign keys to print
