@@ -74,3 +74,26 @@ test_that("output for compound keys", {
       dm_examine_constraints()
   })
 })
+
+# Test unique keys for weak FK (no explicit PK set) -----------------------
+
+test_that("Non-explicit PKs should be tested too", {
+  expect_snapshot(
+    # dm_for_card() has no PKs set, only FKs
+    dm_for_card() %>%
+      dm_examine_constraints()
+  )
+})
+
+test_that("`dm_examine_constraints()` API", {
+  local_options(lifecycle_verbosity = "warning")
+
+  expect_snapshot({
+    dm_examine_constraints(dm_test_obj(), progress = FALSE)
+    dm_examine_constraints(dm = dm_test_obj())
+  })
+
+  expect_snapshot(error = TRUE, {
+    dm_examine_constraints(dm_test_obj(), foo = "bar")
+  })
+})
